# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkess.endpoint import endpoint_data

class CreateEciScalingConfigurationRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ess', '2014-08-28', 'CreateEciScalingConfiguration','ess')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_Containers(self): # RepeatList
		return self.get_query_params().get('Container')

	def set_Containers(self, Container):  # RepeatList
		for depth1 in range(len(Container)):
			if Container[depth1].get('Stdin') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.Stdin', Container[depth1].get('Stdin'))
			if Container[depth1].get('Memory') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.Memory', Container[depth1].get('Memory'))
			if Container[depth1].get('LivenessProbe.Exec.Command') is not None:
				for depth2 in range(len(Container[depth1].get('LivenessProbe.Exec.Command'))):
					self.add_query_param('Container.' + str(depth1 + 1) + '.LivenessProbe.Exec.Command' + str(depth2 + 1), Container[depth1].get('LivenessProbe.Exec.Command')[depth2])
			if Container[depth1].get('WorkingDir') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.WorkingDir', Container[depth1].get('WorkingDir'))
			if Container[depth1].get('ReadinessProbe.HttpGet.Port') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.ReadinessProbe.HttpGet.Port', Container[depth1].get('ReadinessProbe.HttpGet.Port'))
			if Container[depth1].get('ReadinessProbe.FailureThreshold') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.ReadinessProbe.FailureThreshold', Container[depth1].get('ReadinessProbe.FailureThreshold'))
			if Container[depth1].get('LivenessProbe.HttpGet.Port') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.LivenessProbe.HttpGet.Port', Container[depth1].get('LivenessProbe.HttpGet.Port'))
			if Container[depth1].get('Arg') is not None:
				for depth2 in range(len(Container[depth1].get('Arg'))):
					self.add_query_param('Container.' + str(depth1 + 1) + '.Arg' + str(depth2 + 1), Container[depth1].get('Arg')[depth2])
			if Container[depth1].get('ReadinessProbe.SuccessThreshold') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.ReadinessProbe.SuccessThreshold', Container[depth1].get('ReadinessProbe.SuccessThreshold'))
			if Container[depth1].get('VolumeMount') is not None:
				for depth2 in range(len(Container[depth1].get('VolumeMount'))):
					if Container[depth1].get('VolumeMount')[depth2].get('MountPath') is not None:
						self.add_query_param('Container.' + str(depth1 + 1) + str(depth2 + 1) + '.MountPath', Container[depth1].get('VolumeMount')[depth2].get('MountPath'))
					if Container[depth1].get('VolumeMount')[depth2].get('ReadOnly') is not None:
						self.add_query_param('Container.' + str(depth1 + 1) + str(depth2 + 1) + '.ReadOnly', Container[depth1].get('VolumeMount')[depth2].get('ReadOnly'))
					if Container[depth1].get('VolumeMount')[depth2].get('MountPropagation') is not None:
						self.add_query_param('Container.' + str(depth1 + 1) + str(depth2 + 1) + '.MountPropagation', Container[depth1].get('VolumeMount')[depth2].get('MountPropagation'))
					if Container[depth1].get('VolumeMount')[depth2].get('Name') is not None:
						self.add_query_param('Container.' + str(depth1 + 1) + str(depth2 + 1) + '.Name', Container[depth1].get('VolumeMount')[depth2].get('Name'))
					if Container[depth1].get('VolumeMount')[depth2].get('SubPath') is not None:
						self.add_query_param('Container.' + str(depth1 + 1) + str(depth2 + 1) + '.SubPath', Container[depth1].get('VolumeMount')[depth2].get('SubPath'))
			if Container[depth1].get('Image') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.Image', Container[depth1].get('Image'))
			if Container[depth1].get('SecurityContext.Capability.Add') is not None:
				for depth2 in range(len(Container[depth1].get('SecurityContext.Capability.Add'))):
					self.add_query_param('Container.' + str(depth1 + 1) + '.SecurityContext.Capability.Add' + str(depth2 + 1), Container[depth1].get('SecurityContext.Capability.Add')[depth2])
			if Container[depth1].get('ReadinessProbe.InitialDelaySeconds') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.ReadinessProbe.InitialDelaySeconds', Container[depth1].get('ReadinessProbe.InitialDelaySeconds'))
			if Container[depth1].get('Cpu') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.Cpu', Container[depth1].get('Cpu'))
			if Container[depth1].get('ReadinessProbe.Exec.Command') is not None:
				for depth2 in range(len(Container[depth1].get('ReadinessProbe.Exec.Command'))):
					self.add_query_param('Container.' + str(depth1 + 1) + '.ReadinessProbe.Exec.Command' + str(depth2 + 1), Container[depth1].get('ReadinessProbe.Exec.Command')[depth2])
			if Container[depth1].get('ReadinessProbe.HttpGet.Scheme') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.ReadinessProbe.HttpGet.Scheme', Container[depth1].get('ReadinessProbe.HttpGet.Scheme'))
			if Container[depth1].get('ReadinessProbe.HttpGet.Path') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.ReadinessProbe.HttpGet.Path', Container[depth1].get('ReadinessProbe.HttpGet.Path'))
			if Container[depth1].get('Gpu') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.Gpu', Container[depth1].get('Gpu'))
			if Container[depth1].get('StdinOnce') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.StdinOnce', Container[depth1].get('StdinOnce'))
			if Container[depth1].get('ImagePullPolicy') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.ImagePullPolicy', Container[depth1].get('ImagePullPolicy'))
			if Container[depth1].get('Command') is not None:
				for depth2 in range(len(Container[depth1].get('Command'))):
					self.add_query_param('Container.' + str(depth1 + 1) + '.Command' + str(depth2 + 1), Container[depth1].get('Command')[depth2])
			if Container[depth1].get('LivenessProbe.SuccessThreshold') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.LivenessProbe.SuccessThreshold', Container[depth1].get('LivenessProbe.SuccessThreshold'))
			if Container[depth1].get('SecurityContext.RunAsUser') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.SecurityContext.RunAsUser', Container[depth1].get('SecurityContext.RunAsUser'))
			if Container[depth1].get('LivenessProbe.HttpGet.Path') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.LivenessProbe.HttpGet.Path', Container[depth1].get('LivenessProbe.HttpGet.Path'))
			if Container[depth1].get('LivenessProbe.PeriodSeconds') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.LivenessProbe.PeriodSeconds', Container[depth1].get('LivenessProbe.PeriodSeconds'))
			if Container[depth1].get('LivenessProbe.InitialDelaySeconds') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.LivenessProbe.InitialDelaySeconds', Container[depth1].get('LivenessProbe.InitialDelaySeconds'))
			if Container[depth1].get('LivenessProbe.TimeoutSeconds') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.LivenessProbe.TimeoutSeconds', Container[depth1].get('LivenessProbe.TimeoutSeconds'))
			if Container[depth1].get('LivenessProbe.TcpSocket.Port') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.LivenessProbe.TcpSocket.Port', Container[depth1].get('LivenessProbe.TcpSocket.Port'))
			if Container[depth1].get('Port') is not None:
				for depth2 in range(len(Container[depth1].get('Port'))):
					if Container[depth1].get('Port')[depth2].get('Protocol') is not None:
						self.add_query_param('Container.' + str(depth1 + 1) + str(depth2 + 1) + '.Protocol', Container[depth1].get('Port')[depth2].get('Protocol'))
					if Container[depth1].get('Port')[depth2].get('Port') is not None:
						self.add_query_param('Container.' + str(depth1 + 1) + str(depth2 + 1) + '.Port', Container[depth1].get('Port')[depth2].get('Port'))
			if Container[depth1].get('ReadinessProbe.PeriodSeconds') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.ReadinessProbe.PeriodSeconds', Container[depth1].get('ReadinessProbe.PeriodSeconds'))
			if Container[depth1].get('EnvironmentVar') is not None:
				for depth2 in range(len(Container[depth1].get('EnvironmentVar'))):
					if Container[depth1].get('EnvironmentVar')[depth2].get('FieldRefFieldPath') is not None:
						self.add_query_param('Container.' + str(depth1 + 1) + str(depth2 + 1) + '.FieldRefFieldPath', Container[depth1].get('EnvironmentVar')[depth2].get('FieldRefFieldPath'))
					if Container[depth1].get('EnvironmentVar')[depth2].get('Value') is not None:
						self.add_query_param('Container.' + str(depth1 + 1) + str(depth2 + 1) + '.Value', Container[depth1].get('EnvironmentVar')[depth2].get('Value'))
					if Container[depth1].get('EnvironmentVar')[depth2].get('Key') is not None:
						self.add_query_param('Container.' + str(depth1 + 1) + str(depth2 + 1) + '.Key', Container[depth1].get('EnvironmentVar')[depth2].get('Key'))
			if Container[depth1].get('Tty') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.Tty', Container[depth1].get('Tty'))
			if Container[depth1].get('Name') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.Name', Container[depth1].get('Name'))
			if Container[depth1].get('SecurityContext.ReadOnlyRootFilesystem') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.SecurityContext.ReadOnlyRootFilesystem', Container[depth1].get('SecurityContext.ReadOnlyRootFilesystem'))
			if Container[depth1].get('LivenessProbe.FailureThreshold') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.LivenessProbe.FailureThreshold', Container[depth1].get('LivenessProbe.FailureThreshold'))
			if Container[depth1].get('ReadinessProbe.TimeoutSeconds') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.ReadinessProbe.TimeoutSeconds', Container[depth1].get('ReadinessProbe.TimeoutSeconds'))
			if Container[depth1].get('ReadinessProbe.TcpSocket.Port') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.ReadinessProbe.TcpSocket.Port', Container[depth1].get('ReadinessProbe.TcpSocket.Port'))
			if Container[depth1].get('LivenessProbe.HttpGet.Scheme') is not None:
				self.add_query_param('Container.' + str(depth1 + 1) + '.LivenessProbe.HttpGet.Scheme', Container[depth1].get('LivenessProbe.HttpGet.Scheme'))
	def get_NtpServers(self): # RepeatList
		return self.get_query_params().get('NtpServer')

	def set_NtpServers(self, NtpServer):  # RepeatList
		for depth1 in range(len(NtpServer)):
			self.add_query_param('NtpServer.' + str(depth1 + 1), NtpServer[depth1])
	def get_SpotPriceLimit(self): # Float
		return self.get_query_params().get('SpotPriceLimit')

	def set_SpotPriceLimit(self, SpotPriceLimit):  # Float
		self.add_query_param('SpotPriceLimit', SpotPriceLimit)
	def get_ResourceGroupId(self): # String
		return self.get_query_params().get('ResourceGroupId')

	def set_ResourceGroupId(self, ResourceGroupId):  # String
		self.add_query_param('ResourceGroupId', ResourceGroupId)
	def get_HostName(self): # String
		return self.get_query_params().get('HostName')

	def set_HostName(self, HostName):  # String
		self.add_query_param('HostName', HostName)
	def get_ActiveDeadlineSeconds(self): # Long
		return self.get_query_params().get('ActiveDeadlineSeconds')

	def set_ActiveDeadlineSeconds(self, ActiveDeadlineSeconds):  # Long
		self.add_query_param('ActiveDeadlineSeconds', ActiveDeadlineSeconds)
	def get_EgressBandwidth(self): # Long
		return self.get_query_params().get('EgressBandwidth')

	def set_EgressBandwidth(self, EgressBandwidth):  # Long
		self.add_query_param('EgressBandwidth', EgressBandwidth)
	def get_DnsConfigSearchs(self): # RepeatList
		return self.get_query_params().get('DnsConfigSearch')

	def set_DnsConfigSearchs(self, DnsConfigSearch):  # RepeatList
		for depth1 in range(len(DnsConfigSearch)):
			self.add_query_param('DnsConfigSearch.' + str(depth1 + 1), DnsConfigSearch[depth1])
	def get_HostAliases(self): # RepeatList
		return self.get_query_params().get('HostAliase')

	def set_HostAliases(self, HostAliase):  # RepeatList
		for depth1 in range(len(HostAliase)):
			if HostAliase[depth1].get('Hostname') is not None:
				for depth2 in range(len(HostAliase[depth1].get('Hostname'))):
					self.add_query_param('HostAliase.' + str(depth1 + 1) + '.Hostname' + str(depth2 + 1), HostAliase[depth1].get('Hostname')[depth2])
			if HostAliase[depth1].get('Ip') is not None:
				self.add_query_param('HostAliase.' + str(depth1 + 1) + '.Ip', HostAliase[depth1].get('Ip'))
	def get_ImageSnapshotId(self): # String
		return self.get_query_params().get('ImageSnapshotId')

	def set_ImageSnapshotId(self, ImageSnapshotId):  # String
		self.add_query_param('ImageSnapshotId', ImageSnapshotId)
	def get_Tags(self): # RepeatList
		return self.get_query_params().get('Tag')

	def set_Tags(self, Tag):  # RepeatList
		for depth1 in range(len(Tag)):
			if Tag[depth1].get('Value') is not None:
				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
			if Tag[depth1].get('Key') is not None:
				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
	def get_CpuOptionsThreadsPerCore(self): # Integer
		return self.get_query_params().get('CpuOptionsThreadsPerCore')

	def set_CpuOptionsThreadsPerCore(self, CpuOptionsThreadsPerCore):  # Integer
		self.add_query_param('CpuOptionsThreadsPerCore', CpuOptionsThreadsPerCore)
	def get_Ipv6AddressCount(self): # Integer
		return self.get_query_params().get('Ipv6AddressCount')

	def set_Ipv6AddressCount(self, Ipv6AddressCount):  # Integer
		self.add_query_param('Ipv6AddressCount', Ipv6AddressCount)
	def get_Cpu(self): # Float
		return self.get_query_params().get('Cpu')

	def set_Cpu(self, Cpu):  # Float
		self.add_query_param('Cpu', Cpu)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_ScalingConfigurationName(self): # String
		return self.get_query_params().get('ScalingConfigurationName')

	def set_ScalingConfigurationName(self, ScalingConfigurationName):  # String
		self.add_query_param('ScalingConfigurationName', ScalingConfigurationName)
	def get_SpotStrategy(self): # String
		return self.get_query_params().get('SpotStrategy')

	def set_SpotStrategy(self, SpotStrategy):  # String
		self.add_query_param('SpotStrategy', SpotStrategy)
	def get_Volumes(self): # RepeatList
		return self.get_query_params().get('Volume')

	def set_Volumes(self, Volume):  # RepeatList
		for depth1 in range(len(Volume)):
			if Volume[depth1].get('DiskVolume.FsType') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.DiskVolume.FsType', Volume[depth1].get('DiskVolume.FsType'))
			if Volume[depth1].get('NFSVolume.Path') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.NFSVolume.Path', Volume[depth1].get('NFSVolume.Path'))
			if Volume[depth1].get('DiskVolume.DiskId') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.DiskVolume.DiskId', Volume[depth1].get('DiskVolume.DiskId'))
			if Volume[depth1].get('FlexVolume.FsType') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.FlexVolume.FsType', Volume[depth1].get('FlexVolume.FsType'))
			if Volume[depth1].get('Type') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.Type', Volume[depth1].get('Type'))
			if Volume[depth1].get('FlexVolume.Driver') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.FlexVolume.Driver', Volume[depth1].get('FlexVolume.Driver'))
			if Volume[depth1].get('FlexVolume.Options') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.FlexVolume.Options', Volume[depth1].get('FlexVolume.Options'))
			if Volume[depth1].get('NFSVolume.Server') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.NFSVolume.Server', Volume[depth1].get('NFSVolume.Server'))
			if Volume[depth1].get('EmptyDirVolume.Medium') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.EmptyDirVolume.Medium', Volume[depth1].get('EmptyDirVolume.Medium'))
			if Volume[depth1].get('HostPathVolume.Path') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.HostPathVolume.Path', Volume[depth1].get('HostPathVolume.Path'))
			if Volume[depth1].get('Name') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.Name', Volume[depth1].get('Name'))
			if Volume[depth1].get('ConfigFileVolumeConfigFileToPath') is not None:
				for depth2 in range(len(Volume[depth1].get('ConfigFileVolumeConfigFileToPath'))):
					if Volume[depth1].get('ConfigFileVolumeConfigFileToPath')[depth2].get('Mode') is not None:
						self.add_query_param('Volume.' + str(depth1 + 1) + str(depth2 + 1) + '.Mode', Volume[depth1].get('ConfigFileVolumeConfigFileToPath')[depth2].get('Mode'))
					if Volume[depth1].get('ConfigFileVolumeConfigFileToPath')[depth2].get('Path') is not None:
						self.add_query_param('Volume.' + str(depth1 + 1) + str(depth2 + 1) + '.Path', Volume[depth1].get('ConfigFileVolumeConfigFileToPath')[depth2].get('Path'))
					if Volume[depth1].get('ConfigFileVolumeConfigFileToPath')[depth2].get('Content') is not None:
						self.add_query_param('Volume.' + str(depth1 + 1) + str(depth2 + 1) + '.Content', Volume[depth1].get('ConfigFileVolumeConfigFileToPath')[depth2].get('Content'))
			if Volume[depth1].get('DiskVolume.DiskSize') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.DiskVolume.DiskSize', Volume[depth1].get('DiskVolume.DiskSize'))
			if Volume[depth1].get('ConfigFileVolumeDefaultMode') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.ConfigFileVolumeDefaultMode', Volume[depth1].get('ConfigFileVolumeDefaultMode'))
			if Volume[depth1].get('HostPathVolume.Type') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.HostPathVolume.Type', Volume[depth1].get('HostPathVolume.Type'))
			if Volume[depth1].get('NFSVolume.ReadOnly') is not None:
				self.add_query_param('Volume.' + str(depth1 + 1) + '.NFSVolume.ReadOnly', Volume[depth1].get('NFSVolume.ReadOnly'))
	def get_DnsConfigOptions(self): # RepeatList
		return self.get_query_params().get('DnsConfigOption')

	def set_DnsConfigOptions(self, DnsConfigOption):  # RepeatList
		for depth1 in range(len(DnsConfigOption)):
			if DnsConfigOption[depth1].get('Name') is not None:
				self.add_query_param('DnsConfigOption.' + str(depth1 + 1) + '.Name', DnsConfigOption[depth1].get('Name'))
			if DnsConfigOption[depth1].get('Value') is not None:
				self.add_query_param('DnsConfigOption.' + str(depth1 + 1) + '.Value', DnsConfigOption[depth1].get('Value'))
	def get_EphemeralStorage(self): # Integer
		return self.get_query_params().get('EphemeralStorage')

	def set_EphemeralStorage(self, EphemeralStorage):  # Integer
		self.add_query_param('EphemeralStorage', EphemeralStorage)
	def get_EipBandwidth(self): # Integer
		return self.get_query_params().get('EipBandwidth')

	def set_EipBandwidth(self, EipBandwidth):  # Integer
		self.add_query_param('EipBandwidth', EipBandwidth)
	def get_Memory(self): # Float
		return self.get_query_params().get('Memory')

	def set_Memory(self, Memory):  # Float
		self.add_query_param('Memory', Memory)
	def get_ScalingGroupId(self): # String
		return self.get_query_params().get('ScalingGroupId')

	def set_ScalingGroupId(self, ScalingGroupId):  # String
		self.add_query_param('ScalingGroupId', ScalingGroupId)
	def get_SecurityGroupId(self): # String
		return self.get_query_params().get('SecurityGroupId')

	def set_SecurityGroupId(self, SecurityGroupId):  # String
		self.add_query_param('SecurityGroupId', SecurityGroupId)
	def get_IngressBandwidth(self): # Long
		return self.get_query_params().get('IngressBandwidth')

	def set_IngressBandwidth(self, IngressBandwidth):  # Long
		self.add_query_param('IngressBandwidth', IngressBandwidth)
	def get_DnsPolicy(self): # String
		return self.get_query_params().get('DnsPolicy')

	def set_DnsPolicy(self, DnsPolicy):  # String
		self.add_query_param('DnsPolicy', DnsPolicy)
	def get_SecurityContextSysctls(self): # RepeatList
		return self.get_query_params().get('SecurityContextSysctl')

	def set_SecurityContextSysctls(self, SecurityContextSysctl):  # RepeatList
		for depth1 in range(len(SecurityContextSysctl)):
			if SecurityContextSysctl[depth1].get('Name') is not None:
				self.add_query_param('SecurityContextSysctl.' + str(depth1 + 1) + '.Name', SecurityContextSysctl[depth1].get('Name'))
			if SecurityContextSysctl[depth1].get('Value') is not None:
				self.add_query_param('SecurityContextSysctl.' + str(depth1 + 1) + '.Value', SecurityContextSysctl[depth1].get('Value'))
	def get_DnsConfigNameServers(self): # RepeatList
		return self.get_query_params().get('DnsConfigNameServer')

	def set_DnsConfigNameServers(self, DnsConfigNameServer):  # RepeatList
		for depth1 in range(len(DnsConfigNameServer)):
			self.add_query_param('DnsConfigNameServer.' + str(depth1 + 1), DnsConfigNameServer[depth1])
	def get_InitContainers(self): # RepeatList
		return self.get_query_params().get('InitContainer')

	def set_InitContainers(self, InitContainer):  # RepeatList
		for depth1 in range(len(InitContainer)):
			if InitContainer[depth1].get('Image') is not None:
				self.add_query_param('InitContainer.' + str(depth1 + 1) + '.Image', InitContainer[depth1].get('Image'))
			if InitContainer[depth1].get('InitContainerEnvironmentVar') is not None:
				for depth2 in range(len(InitContainer[depth1].get('InitContainerEnvironmentVar'))):
					if InitContainer[depth1].get('InitContainerEnvironmentVar')[depth2].get('FieldRefFieldPath') is not None:
						self.add_query_param('InitContainer.' + str(depth1 + 1) + str(depth2 + 1) + '.FieldRefFieldPath', InitContainer[depth1].get('InitContainerEnvironmentVar')[depth2].get('FieldRefFieldPath'))
					if InitContainer[depth1].get('InitContainerEnvironmentVar')[depth2].get('Value') is not None:
						self.add_query_param('InitContainer.' + str(depth1 + 1) + str(depth2 + 1) + '.Value', InitContainer[depth1].get('InitContainerEnvironmentVar')[depth2].get('Value'))
					if InitContainer[depth1].get('InitContainerEnvironmentVar')[depth2].get('Key') is not None:
						self.add_query_param('InitContainer.' + str(depth1 + 1) + str(depth2 + 1) + '.Key', InitContainer[depth1].get('InitContainerEnvironmentVar')[depth2].get('Key'))
			if InitContainer[depth1].get('SecurityContext.Capability.Add') is not None:
				for depth2 in range(len(InitContainer[depth1].get('SecurityContext.Capability.Add'))):
					self.add_query_param('InitContainer.' + str(depth1 + 1) + '.SecurityContext.Capability.Add' + str(depth2 + 1), InitContainer[depth1].get('SecurityContext.Capability.Add')[depth2])
			if InitContainer[depth1].get('Memory') is not None:
				self.add_query_param('InitContainer.' + str(depth1 + 1) + '.Memory', InitContainer[depth1].get('Memory'))
			if InitContainer[depth1].get('WorkingDir') is not None:
				self.add_query_param('InitContainer.' + str(depth1 + 1) + '.WorkingDir', InitContainer[depth1].get('WorkingDir'))
			if InitContainer[depth1].get('Cpu') is not None:
				self.add_query_param('InitContainer.' + str(depth1 + 1) + '.Cpu', InitContainer[depth1].get('Cpu'))
			if InitContainer[depth1].get('Gpu') is not None:
				self.add_query_param('InitContainer.' + str(depth1 + 1) + '.Gpu', InitContainer[depth1].get('Gpu'))
			if InitContainer[depth1].get('ImagePullPolicy') is not None:
				self.add_query_param('InitContainer.' + str(depth1 + 1) + '.ImagePullPolicy', InitContainer[depth1].get('ImagePullPolicy'))
			if InitContainer[depth1].get('Command') is not None:
				for depth2 in range(len(InitContainer[depth1].get('Command'))):
					self.add_query_param('InitContainer.' + str(depth1 + 1) + '.Command' + str(depth2 + 1), InitContainer[depth1].get('Command')[depth2])
			if InitContainer[depth1].get('SecurityContext.RunAsUser') is not None:
				self.add_query_param('InitContainer.' + str(depth1 + 1) + '.SecurityContext.RunAsUser', InitContainer[depth1].get('SecurityContext.RunAsUser'))
			if InitContainer[depth1].get('InitContainerPort') is not None:
				for depth2 in range(len(InitContainer[depth1].get('InitContainerPort'))):
					if InitContainer[depth1].get('InitContainerPort')[depth2].get('Protocol') is not None:
						self.add_query_param('InitContainer.' + str(depth1 + 1) + str(depth2 + 1) + '.Protocol', InitContainer[depth1].get('InitContainerPort')[depth2].get('Protocol'))
					if InitContainer[depth1].get('InitContainerPort')[depth2].get('Port') is not None:
						self.add_query_param('InitContainer.' + str(depth1 + 1) + str(depth2 + 1) + '.Port', InitContainer[depth1].get('InitContainerPort')[depth2].get('Port'))
			if InitContainer[depth1].get('Arg') is not None:
				for depth2 in range(len(InitContainer[depth1].get('Arg'))):
					self.add_query_param('InitContainer.' + str(depth1 + 1) + '.Arg' + str(depth2 + 1), InitContainer[depth1].get('Arg')[depth2])
			if InitContainer[depth1].get('Name') is not None:
				self.add_query_param('InitContainer.' + str(depth1 + 1) + '.Name', InitContainer[depth1].get('Name'))
			if InitContainer[depth1].get('InitContainerVolumeMount') is not None:
				for depth2 in range(len(InitContainer[depth1].get('InitContainerVolumeMount'))):
					if InitContainer[depth1].get('InitContainerVolumeMount')[depth2].get('MountPath') is not None:
						self.add_query_param('InitContainer.' + str(depth1 + 1) + str(depth2 + 1) + '.MountPath', InitContainer[depth1].get('InitContainerVolumeMount')[depth2].get('MountPath'))
					if InitContainer[depth1].get('InitContainerVolumeMount')[depth2].get('ReadOnly') is not None:
						self.add_query_param('InitContainer.' + str(depth1 + 1) + str(depth2 + 1) + '.ReadOnly', InitContainer[depth1].get('InitContainerVolumeMount')[depth2].get('ReadOnly'))
					if InitContainer[depth1].get('InitContainerVolumeMount')[depth2].get('MountPropagation') is not None:
						self.add_query_param('InitContainer.' + str(depth1 + 1) + str(depth2 + 1) + '.MountPropagation', InitContainer[depth1].get('InitContainerVolumeMount')[depth2].get('MountPropagation'))
					if InitContainer[depth1].get('InitContainerVolumeMount')[depth2].get('Name') is not None:
						self.add_query_param('InitContainer.' + str(depth1 + 1) + str(depth2 + 1) + '.Name', InitContainer[depth1].get('InitContainerVolumeMount')[depth2].get('Name'))
					if InitContainer[depth1].get('InitContainerVolumeMount')[depth2].get('SubPath') is not None:
						self.add_query_param('InitContainer.' + str(depth1 + 1) + str(depth2 + 1) + '.SubPath', InitContainer[depth1].get('InitContainerVolumeMount')[depth2].get('SubPath'))
			if InitContainer[depth1].get('SecurityContext.ReadOnlyRootFilesystem') is not None:
				self.add_query_param('InitContainer.' + str(depth1 + 1) + '.SecurityContext.ReadOnlyRootFilesystem', InitContainer[depth1].get('SecurityContext.ReadOnlyRootFilesystem'))
	def get_TerminationGracePeriodSeconds(self): # Long
		return self.get_query_params().get('TerminationGracePeriodSeconds')

	def set_TerminationGracePeriodSeconds(self, TerminationGracePeriodSeconds):  # Long
		self.add_query_param('TerminationGracePeriodSeconds', TerminationGracePeriodSeconds)
	def get_ImageRegistryCredentials(self): # RepeatList
		return self.get_query_params().get('ImageRegistryCredential')

	def set_ImageRegistryCredentials(self, ImageRegistryCredential):  # RepeatList
		for depth1 in range(len(ImageRegistryCredential)):
			if ImageRegistryCredential[depth1].get('Server') is not None:
				self.add_query_param('ImageRegistryCredential.' + str(depth1 + 1) + '.Server', ImageRegistryCredential[depth1].get('Server'))
			if ImageRegistryCredential[depth1].get('Password') is not None:
				self.add_query_param('ImageRegistryCredential.' + str(depth1 + 1) + '.Password', ImageRegistryCredential[depth1].get('Password'))
			if ImageRegistryCredential[depth1].get('UserName') is not None:
				self.add_query_param('ImageRegistryCredential.' + str(depth1 + 1) + '.UserName', ImageRegistryCredential[depth1].get('UserName'))
	def get_ResourceOwnerAccount(self): # String
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
	def get_RestartPolicy(self): # String
		return self.get_query_params().get('RestartPolicy')

	def set_RestartPolicy(self, RestartPolicy):  # String
		self.add_query_param('RestartPolicy', RestartPolicy)
	def get_CpuOptionsCore(self): # Integer
		return self.get_query_params().get('CpuOptionsCore')

	def set_CpuOptionsCore(self, CpuOptionsCore):  # Integer
		self.add_query_param('CpuOptionsCore', CpuOptionsCore)
	def get_RamRoleName(self): # String
		return self.get_query_params().get('RamRoleName')

	def set_RamRoleName(self, RamRoleName):  # String
		self.add_query_param('RamRoleName', RamRoleName)
	def get_AcrRegistryInfos(self): # RepeatList
		return self.get_query_params().get('AcrRegistryInfo')

	def set_AcrRegistryInfos(self, AcrRegistryInfo):  # RepeatList
		for depth1 in range(len(AcrRegistryInfo)):
			if AcrRegistryInfo[depth1].get('InstanceName') is not None:
				self.add_query_param('AcrRegistryInfo.' + str(depth1 + 1) + '.InstanceName', AcrRegistryInfo[depth1].get('InstanceName'))
			if AcrRegistryInfo[depth1].get('InstanceId') is not None:
				self.add_query_param('AcrRegistryInfo.' + str(depth1 + 1) + '.InstanceId', AcrRegistryInfo[depth1].get('InstanceId'))
			if AcrRegistryInfo[depth1].get('RegionId') is not None:
				self.add_query_param('AcrRegistryInfo.' + str(depth1 + 1) + '.RegionId', AcrRegistryInfo[depth1].get('RegionId'))
			if AcrRegistryInfo[depth1].get('Domain') is not None:
				for depth2 in range(len(AcrRegistryInfo[depth1].get('Domain'))):
					self.add_query_param('AcrRegistryInfo.' + str(depth1 + 1) + '.Domain' + str(depth2 + 1), AcrRegistryInfo[depth1].get('Domain')[depth2])
	def get_AutoMatchImageCache(self): # Boolean
		return self.get_query_params().get('AutoMatchImageCache')

	def set_AutoMatchImageCache(self, AutoMatchImageCache):  # Boolean
		self.add_query_param('AutoMatchImageCache', AutoMatchImageCache)
	def get_LoadBalancerWeight(self): # Integer
		return self.get_query_params().get('LoadBalancerWeight')

	def set_LoadBalancerWeight(self, LoadBalancerWeight):  # Integer
		self.add_query_param('LoadBalancerWeight', LoadBalancerWeight)
	def get_ContainerGroupName(self): # String
		return self.get_query_params().get('ContainerGroupName')

	def set_ContainerGroupName(self, ContainerGroupName):  # String
		self.add_query_param('ContainerGroupName', ContainerGroupName)
	def get_AutoCreateEip(self): # Boolean
		return self.get_query_params().get('AutoCreateEip')

	def set_AutoCreateEip(self, AutoCreateEip):  # Boolean
		self.add_query_param('AutoCreateEip', AutoCreateEip)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkess.endpoint import endpoint_data

class CreateScalingRuleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ess', '2014-08-28', 'CreateScalingRule','ess')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_StepAdjustments(self): # RepeatList
		return self.get_query_params().get('StepAdjustment')

	def set_StepAdjustments(self, StepAdjustment):  # RepeatList
		for depth1 in range(len(StepAdjustment)):
			if StepAdjustment[depth1].get('MetricIntervalUpperBound') is not None:
				self.add_query_param('StepAdjustment.' + str(depth1 + 1) + '.MetricIntervalUpperBound', StepAdjustment[depth1].get('MetricIntervalUpperBound'))
			if StepAdjustment[depth1].get('MetricIntervalLowerBound') is not None:
				self.add_query_param('StepAdjustment.' + str(depth1 + 1) + '.MetricIntervalLowerBound', StepAdjustment[depth1].get('MetricIntervalLowerBound'))
			if StepAdjustment[depth1].get('ScalingAdjustment') is not None:
				self.add_query_param('StepAdjustment.' + str(depth1 + 1) + '.ScalingAdjustment', StepAdjustment[depth1].get('ScalingAdjustment'))
	def get_ScalingGroupId(self): # String
		return self.get_query_params().get('ScalingGroupId')

	def set_ScalingGroupId(self, ScalingGroupId):  # String
		self.add_query_param('ScalingGroupId', ScalingGroupId)
	def get_DisableScaleIn(self): # Boolean
		return self.get_query_params().get('DisableScaleIn')

	def set_DisableScaleIn(self, DisableScaleIn):  # Boolean
		self.add_query_param('DisableScaleIn', DisableScaleIn)
	def get_InitialMaxSize(self): # Integer
		return self.get_query_params().get('InitialMaxSize')

	def set_InitialMaxSize(self, InitialMaxSize):  # Integer
		self.add_query_param('InitialMaxSize', InitialMaxSize)
	def get_ScalingRuleName(self): # String
		return self.get_query_params().get('ScalingRuleName')

	def set_ScalingRuleName(self, ScalingRuleName):  # String
		self.add_query_param('ScalingRuleName', ScalingRuleName)
	def get_Cooldown(self): # Integer
		return self.get_query_params().get('Cooldown')

	def set_Cooldown(self, Cooldown):  # Integer
		self.add_query_param('Cooldown', Cooldown)
	def get_PredictiveValueBehavior(self): # String
		return self.get_query_params().get('PredictiveValueBehavior')

	def set_PredictiveValueBehavior(self, PredictiveValueBehavior):  # String
		self.add_query_param('PredictiveValueBehavior', PredictiveValueBehavior)
	def get_ScaleInEvaluationCount(self): # Integer
		return self.get_query_params().get('ScaleInEvaluationCount')

	def set_ScaleInEvaluationCount(self, ScaleInEvaluationCount):  # Integer
		self.add_query_param('ScaleInEvaluationCount', ScaleInEvaluationCount)
	def get_ScalingRuleType(self): # String
		return self.get_query_params().get('ScalingRuleType')

	def set_ScalingRuleType(self, ScalingRuleType):  # String
		self.add_query_param('ScalingRuleType', ScalingRuleType)
	def get_MetricName(self): # String
		return self.get_query_params().get('MetricName')

	def set_MetricName(self, MetricName):  # String
		self.add_query_param('MetricName', MetricName)
	def get_PredictiveScalingMode(self): # String
		return self.get_query_params().get('PredictiveScalingMode')

	def set_PredictiveScalingMode(self, PredictiveScalingMode):  # String
		self.add_query_param('PredictiveScalingMode', PredictiveScalingMode)
	def get_ResourceOwnerAccount(self): # String
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
	def get_AdjustmentValue(self): # Integer
		return self.get_query_params().get('AdjustmentValue')

	def set_AdjustmentValue(self, AdjustmentValue):  # Integer
		self.add_query_param('AdjustmentValue', AdjustmentValue)
	def get_EstimatedInstanceWarmup(self): # Integer
		return self.get_query_params().get('EstimatedInstanceWarmup')

	def set_EstimatedInstanceWarmup(self, EstimatedInstanceWarmup):  # Integer
		self.add_query_param('EstimatedInstanceWarmup', EstimatedInstanceWarmup)
	def get_OwnerAccount(self): # String
		return self.get_query_params().get('OwnerAccount')

	def set_OwnerAccount(self, OwnerAccount):  # String
		self.add_query_param('OwnerAccount', OwnerAccount)
	def get_PredictiveTaskBufferTime(self): # Integer
		return self.get_query_params().get('PredictiveTaskBufferTime')

	def set_PredictiveTaskBufferTime(self, PredictiveTaskBufferTime):  # Integer
		self.add_query_param('PredictiveTaskBufferTime', PredictiveTaskBufferTime)
	def get_AdjustmentType(self): # String
		return self.get_query_params().get('AdjustmentType')

	def set_AdjustmentType(self, AdjustmentType):  # String
		self.add_query_param('AdjustmentType', AdjustmentType)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_PredictiveValueBuffer(self): # Integer
		return self.get_query_params().get('PredictiveValueBuffer')

	def set_PredictiveValueBuffer(self, PredictiveValueBuffer):  # Integer
		self.add_query_param('PredictiveValueBuffer', PredictiveValueBuffer)
	def get_ScaleOutEvaluationCount(self): # Integer
		return self.get_query_params().get('ScaleOutEvaluationCount')

	def set_ScaleOutEvaluationCount(self, ScaleOutEvaluationCount):  # Integer
		self.add_query_param('ScaleOutEvaluationCount', ScaleOutEvaluationCount)
	def get_MinAdjustmentMagnitude(self): # Integer
		return self.get_query_params().get('MinAdjustmentMagnitude')

	def set_MinAdjustmentMagnitude(self, MinAdjustmentMagnitude):  # Integer
		self.add_query_param('MinAdjustmentMagnitude', MinAdjustmentMagnitude)
	def get_TargetValue(self): # Float
		return self.get_query_params().get('TargetValue')

	def set_TargetValue(self, TargetValue):  # Float
		self.add_query_param('TargetValue', TargetValue)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkess.endpoint import endpoint_data

class CreateScalingGroupRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ess', '2014-08-28', 'CreateScalingGroup','ess')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_VSwitchIdss(self): # RepeatList
		return self.get_query_params().get('VSwitchIds')

	def set_VSwitchIdss(self, VSwitchIds):  # RepeatList
		for depth1 in range(len(VSwitchIds)):
			self.add_query_param('VSwitchIds.' + str(depth1 + 1), VSwitchIds[depth1])
	def get_SpotInstanceRemedy(self): # Boolean
		return self.get_query_params().get('SpotInstanceRemedy')

	def set_SpotInstanceRemedy(self, SpotInstanceRemedy):  # Boolean
		self.add_query_param('SpotInstanceRemedy', SpotInstanceRemedy)
	def get_GroupType(self): # String
		return self.get_query_params().get('GroupType')

	def set_GroupType(self, GroupType):  # String
		self.add_query_param('GroupType', GroupType)
	def get_Tags(self): # RepeatList
		return self.get_query_params().get('Tag')

	def set_Tags(self, Tag):  # RepeatList
		for depth1 in range(len(Tag)):
			if Tag[depth1].get('Value') is not None:
				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
			if Tag[depth1].get('Key') is not None:
				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
	def get_DefaultCooldown(self): # Integer
		return self.get_query_params().get('DefaultCooldown')

	def set_DefaultCooldown(self, DefaultCooldown):  # Integer
		self.add_query_param('DefaultCooldown', DefaultCooldown)
	def get_ContainerGroupId(self): # String
		return self.get_query_params().get('ContainerGroupId')

	def set_ContainerGroupId(self, ContainerGroupId):  # String
		self.add_query_param('ContainerGroupId', ContainerGroupId)
	def get_MultiAZPolicy(self): # String
		return self.get_query_params().get('MultiAZPolicy')

	def set_MultiAZPolicy(self, MultiAZPolicy):  # String
		self.add_query_param('MultiAZPolicy', MultiAZPolicy)
	def get_DBInstanceIds(self): # String
		return self.get_query_params().get('DBInstanceIds')

	def set_DBInstanceIds(self, DBInstanceIds):  # String
		self.add_query_param('DBInstanceIds', DBInstanceIds)
	def get_LaunchTemplateId(self): # String
		return self.get_query_params().get('LaunchTemplateId')

	def set_LaunchTemplateId(self, LaunchTemplateId):  # String
		self.add_query_param('LaunchTemplateId', LaunchTemplateId)
	def get_DesiredCapacity(self): # Integer
		return self.get_query_params().get('DesiredCapacity')

	def set_DesiredCapacity(self, DesiredCapacity):  # Integer
		self.add_query_param('DesiredCapacity', DesiredCapacity)
	def get_LaunchTemplateOverrides(self): # RepeatList
		return self.get_query_params().get('LaunchTemplateOverride')

	def set_LaunchTemplateOverrides(self, LaunchTemplateOverride):  # RepeatList
		for depth1 in range(len(LaunchTemplateOverride)):
			if LaunchTemplateOverride[depth1].get('WeightedCapacity') is not None:
				self.add_query_param('LaunchTemplateOverride.' + str(depth1 + 1) + '.WeightedCapacity', LaunchTemplateOverride[depth1].get('WeightedCapacity'))
			if LaunchTemplateOverride[depth1].get('InstanceType') is not None:
				self.add_query_param('LaunchTemplateOverride.' + str(depth1 + 1) + '.InstanceType', LaunchTemplateOverride[depth1].get('InstanceType'))
	def get_CompensateWithOnDemand(self): # Boolean
		return self.get_query_params().get('CompensateWithOnDemand')

	def set_CompensateWithOnDemand(self, CompensateWithOnDemand):  # Boolean
		self.add_query_param('CompensateWithOnDemand', CompensateWithOnDemand)
	def get_MinSize(self): # Integer
		return self.get_query_params().get('MinSize')

	def set_MinSize(self, MinSize):  # Integer
		self.add_query_param('MinSize', MinSize)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_AlbServerGroups(self): # RepeatList
		return self.get_query_params().get('AlbServerGroup')

	def set_AlbServerGroups(self, AlbServerGroup):  # RepeatList
		for depth1 in range(len(AlbServerGroup)):
			if AlbServerGroup[depth1].get('AlbServerGroupId') is not None:
				self.add_query_param('AlbServerGroup.' + str(depth1 + 1) + '.AlbServerGroupId', AlbServerGroup[depth1].get('AlbServerGroupId'))
			if AlbServerGroup[depth1].get('Port') is not None:
				self.add_query_param('AlbServerGroup.' + str(depth1 + 1) + '.Port', AlbServerGroup[depth1].get('Port'))
			if AlbServerGroup[depth1].get('Weight') is not None:
				self.add_query_param('AlbServerGroup.' + str(depth1 + 1) + '.Weight', AlbServerGroup[depth1].get('Weight'))
	def get_VSwitchId(self): # String
		return self.get_query_params().get('VSwitchId')

	def set_VSwitchId(self, VSwitchId):  # String
		self.add_query_param('VSwitchId', VSwitchId)
	def get_InstanceId(self): # String
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self, InstanceId):  # String
		self.add_query_param('InstanceId', InstanceId)
	def get_MaxSize(self): # Integer
		return self.get_query_params().get('MaxSize')

	def set_MaxSize(self, MaxSize):  # Integer
		self.add_query_param('MaxSize', MaxSize)
	def get_LifecycleHooks(self): # RepeatList
		return self.get_query_params().get('LifecycleHook')

	def set_LifecycleHooks(self, LifecycleHook):  # RepeatList
		for depth1 in range(len(LifecycleHook)):
			if LifecycleHook[depth1].get('DefaultResult') is not None:
				self.add_query_param('LifecycleHook.' + str(depth1 + 1) + '.DefaultResult', LifecycleHook[depth1].get('DefaultResult'))
			if LifecycleHook[depth1].get('LifecycleHookName') is not None:
				self.add_query_param('LifecycleHook.' + str(depth1 + 1) + '.LifecycleHookName', LifecycleHook[depth1].get('LifecycleHookName'))
			if LifecycleHook[depth1].get('HeartbeatTimeout') is not None:
				self.add_query_param('LifecycleHook.' + str(depth1 + 1) + '.HeartbeatTimeout', LifecycleHook[depth1].get('HeartbeatTimeout'))
			if LifecycleHook[depth1].get('NotificationArn') is not None:
				self.add_query_param('LifecycleHook.' + str(depth1 + 1) + '.NotificationArn', LifecycleHook[depth1].get('NotificationArn'))
			if LifecycleHook[depth1].get('NotificationMetadata') is not None:
				self.add_query_param('LifecycleHook.' + str(depth1 + 1) + '.NotificationMetadata', LifecycleHook[depth1].get('NotificationMetadata'))
			if LifecycleHook[depth1].get('LifecycleTransition') is not None:
				self.add_query_param('LifecycleHook.' + str(depth1 + 1) + '.LifecycleTransition', LifecycleHook[depth1].get('LifecycleTransition'))
	def get_LoadBalancerIds(self): # String
		return self.get_query_params().get('LoadBalancerIds')

	def set_LoadBalancerIds(self, LoadBalancerIds):  # String
		self.add_query_param('LoadBalancerIds', LoadBalancerIds)
	def get_ClientToken(self): # String
		return self.get_query_params().get('ClientToken')

	def set_ClientToken(self, ClientToken):  # String
		self.add_query_param('ClientToken', ClientToken)
	def get_OnDemandBaseCapacity(self): # Integer
		return self.get_query_params().get('OnDemandBaseCapacity')

	def set_OnDemandBaseCapacity(self, OnDemandBaseCapacity):  # Integer
		self.add_query_param('OnDemandBaseCapacity', OnDemandBaseCapacity)
	def get_OnDemandPercentageAboveBaseCapacity(self): # Integer
		return self.get_query_params().get('OnDemandPercentageAboveBaseCapacity')

	def set_OnDemandPercentageAboveBaseCapacity(self, OnDemandPercentageAboveBaseCapacity):  # Integer
		self.add_query_param('OnDemandPercentageAboveBaseCapacity', OnDemandPercentageAboveBaseCapacity)
	def get_RemovalPolicy1(self): # String
		return self.get_query_params().get('RemovalPolicy.1')

	def set_RemovalPolicy1(self, RemovalPolicy1):  # String
		self.add_query_param('RemovalPolicy.1', RemovalPolicy1)
	def get_RemovalPolicy2(self): # String
		return self.get_query_params().get('RemovalPolicy.2')

	def set_RemovalPolicy2(self, RemovalPolicy2):  # String
		self.add_query_param('RemovalPolicy.2', RemovalPolicy2)
	def get_HealthCheckType(self): # String
		return self.get_query_params().get('HealthCheckType')

	def set_HealthCheckType(self, HealthCheckType):  # String
		self.add_query_param('HealthCheckType', HealthCheckType)
	def get_ResourceOwnerAccount(self): # String
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
	def get_ScalingGroupName(self): # String
		return self.get_query_params().get('ScalingGroupName')

	def set_ScalingGroupName(self, ScalingGroupName):  # String
		self.add_query_param('ScalingGroupName', ScalingGroupName)
	def get_OwnerAccount(self): # String
		return self.get_query_params().get('OwnerAccount')

	def set_OwnerAccount(self, OwnerAccount):  # String
		self.add_query_param('OwnerAccount', OwnerAccount)
	def get_SpotInstancePools(self): # Integer
		return self.get_query_params().get('SpotInstancePools')

	def set_SpotInstancePools(self, SpotInstancePools):  # Integer
		self.add_query_param('SpotInstancePools', SpotInstancePools)
	def get_GroupDeletionProtection(self): # Boolean
		return self.get_query_params().get('GroupDeletionProtection')

	def set_GroupDeletionProtection(self, GroupDeletionProtection):  # Boolean
		self.add_query_param('GroupDeletionProtection', GroupDeletionProtection)
	def get_LaunchTemplateVersion(self): # String
		return self.get_query_params().get('LaunchTemplateVersion')

	def set_LaunchTemplateVersion(self, LaunchTemplateVersion):  # String
		self.add_query_param('LaunchTemplateVersion', LaunchTemplateVersion)
	def get_ScalingPolicy(self): # String
		return self.get_query_params().get('ScalingPolicy')

	def set_ScalingPolicy(self, ScalingPolicy):  # String
		self.add_query_param('ScalingPolicy', ScalingPolicy)
	def get_VServerGroups(self): # RepeatList
		return self.get_query_params().get('VServerGroup')

	def set_VServerGroups(self, VServerGroup):  # RepeatList
		for depth1 in range(len(VServerGroup)):
			if VServerGroup[depth1].get('LoadBalancerId') is not None:
				self.add_query_param('VServerGroup.' + str(depth1 + 1) + '.LoadBalancerId', VServerGroup[depth1].get('LoadBalancerId'))
			if VServerGroup[depth1].get('VServerGroupAttribute') is not None:
				for depth2 in range(len(VServerGroup[depth1].get('VServerGroupAttribute'))):
					if VServerGroup[depth1].get('VServerGroupAttribute')[depth2].get('VServerGroupId') is not None:
						self.add_query_param('VServerGroup.' + str(depth1 + 1) + str(depth2 + 1) + '.VServerGroupId', VServerGroup[depth1].get('VServerGroupAttribute')[depth2].get('VServerGroupId'))
					if VServerGroup[depth1].get('VServerGroupAttribute')[depth2].get('Port') is not None:
						self.add_query_param('VServerGroup.' + str(depth1 + 1) + str(depth2 + 1) + '.Port', VServerGroup[depth1].get('VServerGroupAttribute')[depth2].get('Port'))
					if VServerGroup[depth1].get('VServerGroupAttribute')[depth2].get('Weight') is not None:
						self.add_query_param('VServerGroup.' + str(depth1 + 1) + str(depth2 + 1) + '.Weight', VServerGroup[depth1].get('VServerGroupAttribute')[depth2].get('Weight'))



# # Licensed to the Apache Software Foundation (ASF) under one
# # or more contributor license agreements.  See the NOTICE file
# # distributed with this work for additional information
# # regarding copyright ownership.  The ASF licenses this file
# # to you under the Apache License, Version 2.0 (the
# # "License"); you may not use this file except in compliance
# # with the License.  You may obtain a copy of the License at
# #
# #
# #     http://www.apache.org/licenses/LICENSE-2.0
# #
# #
# # Unless required by applicable law or agreed to in writing,
# # software distributed under the License is distributed on an
# # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# # KIND, either express or implied.  See the License for the
# # specific language governing permissions and limitations
# # under the License.


class EndpointData():
	def __init__(self):
		self.endpoint_map = {
			"cn-shanghai-internal-test-1": "ess.aliyuncs.com",
			"cn-beijing-gov-1": "ess.aliyuncs.com",
			"cn-shenzhen-su18-b01": "ess.aliyuncs.com",
			"cn-beijing": "ess.aliyuncs.com",
			"cn-shanghai-inner": "ess.aliyuncs.com",
			"cn-shenzhen-st4-d01": "ess.aliyuncs.com",
			"cn-haidian-cm12-c01": "ess.aliyuncs.com",
			"cn-hangzhou-internal-prod-1": "ess.aliyuncs.com",
			"cn-north-2-gov-1": "ess.aliyuncs.com",
			"cn-yushanfang": "ess.aliyuncs.com",
			"cn-qingdao": "ess.aliyuncs.com",
			"cn-hongkong-finance-pop": "ess.aliyuncs.com",
			"cn-qingdao-nebula": "ess.aliyuncs.com",
			"cn-shanghai": "ess.aliyuncs.com",
			"cn-shanghai-finance-1": "ess.aliyuncs.com",
			"cn-hongkong": "ess.aliyuncs.com",
			"cn-beijing-finance-pop": "ess.aliyuncs.com",
			"cn-wuhan": "ess.aliyuncs.com",
			"us-west-1": "ess.aliyuncs.com",
			"cn-zhangbei": "ess.aliyuncs.com",
			"cn-shenzhen": "ess.aliyuncs.com",
			"cn-zhengzhou-nebula-1": "ess.aliyuncs.com",
			"rus-west-1-pop": "ess.aliyuncs.com",
			"cn-shanghai-et15-b01": "ess.aliyuncs.com",
			"cn-hangzhou-bj-b01": "ess.aliyuncs.com",
			"cn-hangzhou-internal-test-1": "ess.aliyuncs.com",
			"eu-west-1-oxs": "ess.aliyuncs.com",
			"cn-zhangbei-na61-b01": "ess.aliyuncs.com",
			"cn-beijing-finance-1": "ess.aliyuncs.com",
			"cn-hangzhou-internal-test-3": "ess.aliyuncs.com",
			"cn-shenzhen-finance-1": "ess.aliyuncs.com",
			"cn-hangzhou-internal-test-2": "ess.aliyuncs.com",
			"cn-hangzhou-test-306": "ess.aliyuncs.com",
			"cn-huhehaote-nebula-1": "ess.aliyuncs.com",
			"cn-shanghai-et2-b01": "ess.aliyuncs.com",
			"cn-hangzhou-finance": "ess.aliyuncs.com",
			"ap-southeast-1": "ess.aliyuncs.com",
			"cn-beijing-nu16-b01": "ess.aliyuncs.com",
			"cn-edge-1": "ess.aliyuncs.com",
			"us-east-1": "ess.aliyuncs.com",
			"cn-fujian": "ess.aliyuncs.com",
			"ap-northeast-2-pop": "ess.aliyuncs.com",
			"cn-shenzhen-inner": "ess.aliyuncs.com",
			"cn-zhangjiakou-na62-a01": "ess.aliyuncs.com",
			"cn-hangzhou": "ess.aliyuncs.com",
		}
		self.endpoint_regional = "regional"

	def getEndpointMap(self):
		return self.endpoint_map

	def getEndpointRegional(self):
		return self.endpoint_regional


endpoint_data = EndpointData()



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkess.endpoint import endpoint_data

class DescribeScalingGroupsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ess', '2014-08-28', 'DescribeScalingGroups','ess')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ResourceOwnerId(self): # Long
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
	def get_GroupType(self): # String
		return self.get_query_params().get('GroupType')

	def set_GroupType(self, GroupType):  # String
		self.add_query_param('GroupType', GroupType)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_ScalingGroupIds(self): # RepeatList
		return self.get_query_params().get('ScalingGroupId')

	def set_ScalingGroupIds(self, ScalingGroupId):  # RepeatList
		for depth1 in range(len(ScalingGroupId)):
			self.add_query_param('ScalingGroupId.' + str(depth1 + 1), ScalingGroupId[depth1])
	def get_PageNumber(self): # Integer
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self, PageNumber):  # Integer
		self.add_query_param('PageNumber', PageNumber)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_ScalingGroupName20(self): # String
		return self.get_query_params().get('ScalingGroupName.20')

	def set_ScalingGroupName20(self, ScalingGroupName20):  # String
		self.add_query_param('ScalingGroupName.20', ScalingGroupName20)
	def get_ScalingGroupName19(self): # String
		return self.get_query_params().get('ScalingGroupName.19')

	def set_ScalingGroupName19(self, ScalingGroupName19):  # String
		self.add_query_param('ScalingGroupName.19', ScalingGroupName19)
	def get_ScalingGroupName18(self): # String
		return self.get_query_params().get('ScalingGroupName.18')

	def set_ScalingGroupName18(self, ScalingGroupName18):  # String
		self.add_query_param('ScalingGroupName.18', ScalingGroupName18)
	def get_ScalingGroupName17(self): # String
		return self.get_query_params().get('ScalingGroupName.17')

	def set_ScalingGroupName17(self, ScalingGroupName17):  # String
		self.add_query_param('ScalingGroupName.17', ScalingGroupName17)
	def get_ScalingGroupName16(self): # String
		return self.get_query_params().get('ScalingGroupName.16')

	def set_ScalingGroupName16(self, ScalingGroupName16):  # String
		self.add_query_param('ScalingGroupName.16', ScalingGroupName16)
	def get_ResourceOwnerAccount(self): # String
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
	def get_ScalingGroupName(self): # String
		return self.get_query_params().get('ScalingGroupName')

	def set_ScalingGroupName(self, ScalingGroupName):  # String
		self.add_query_param('ScalingGroupName', ScalingGroupName)
	def get_OwnerAccount(self): # String
		return self.get_query_params().get('OwnerAccount')

	def set_OwnerAccount(self, OwnerAccount):  # String
		self.add_query_param('OwnerAccount', OwnerAccount)
	def get_ScalingGroupName1(self): # String
		return self.get_query_params().get('ScalingGroupName.1')

	def set_ScalingGroupName1(self, ScalingGroupName1):  # String
		self.add_query_param('ScalingGroupName.1', ScalingGroupName1)
	def get_ScalingGroupName2(self): # String
		return self.get_query_params().get('ScalingGroupName.2')

	def set_ScalingGroupName2(self, ScalingGroupName2):  # String
		self.add_query_param('ScalingGroupName.2', ScalingGroupName2)
	def get_ScalingGroupName7(self): # String
		return self.get_query_params().get('ScalingGroupName.7')

	def set_ScalingGroupName7(self, ScalingGroupName7):  # String
		self.add_query_param('ScalingGroupName.7', ScalingGroupName7)
	def get_ScalingGroupName11(self): # String
		return self.get_query_params().get('ScalingGroupName.11')

	def set_ScalingGroupName11(self, ScalingGroupName11):  # String
		self.add_query_param('ScalingGroupName.11', ScalingGroupName11)
	def get_ScalingGroupName8(self): # String
		return self.get_query_params().get('ScalingGroupName.8')

	def set_ScalingGroupName8(self, ScalingGroupName8):  # String
		self.add_query_param('ScalingGroupName.8', ScalingGroupName8)
	def get_ScalingGroupName10(self): # String
		return self.get_query_params().get('ScalingGroupName.10')

	def set_ScalingGroupName10(self, ScalingGroupName10):  # String
		self.add_query_param('ScalingGroupName.10', ScalingGroupName10)
	def get_ScalingGroupName9(self): # String
		return self.get_query_params().get('ScalingGroupName.9')

	def set_ScalingGroupName9(self, ScalingGroupName9):  # String
		self.add_query_param('ScalingGroupName.9', ScalingGroupName9)
	def get_ScalingGroupName3(self): # String
		return self.get_query_params().get('ScalingGroupName.3')

	def set_ScalingGroupName3(self, ScalingGroupName3):  # String
		self.add_query_param('ScalingGroupName.3', ScalingGroupName3)
	def get_ScalingGroupName15(self): # String
		return self.get_query_params().get('ScalingGroupName.15')

	def set_ScalingGroupName15(self, ScalingGroupName15):  # String
		self.add_query_param('ScalingGroupName.15', ScalingGroupName15)
	def get_ScalingGroupName4(self): # String
		return self.get_query_params().get('ScalingGroupName.4')

	def set_ScalingGroupName4(self, ScalingGroupName4):  # String
		self.add_query_param('ScalingGroupName.4', ScalingGroupName4)
	def get_ScalingGroupName14(self): # String
		return self.get_query_params().get('ScalingGroupName.14')

	def set_ScalingGroupName14(self, ScalingGroupName14):  # String
		self.add_query_param('ScalingGroupName.14', ScalingGroupName14)
	def get_ScalingGroupName5(self): # String
		return self.get_query_params().get('ScalingGroupName.5')

	def set_ScalingGroupName5(self, ScalingGroupName5):  # String
		self.add_query_param('ScalingGroupName.5', ScalingGroupName5)
	def get_ScalingGroupName13(self): # String
		return self.get_query_params().get('ScalingGroupName.13')

	def set_ScalingGroupName13(self, ScalingGroupName13):  # String
		self.add_query_param('ScalingGroupName.13', ScalingGroupName13)
	def get_ScalingGroupName6(self): # String
		return self.get_query_params().get('ScalingGroupName.6')

	def set_ScalingGroupName6(self, ScalingGroupName6):  # String
		self.add_query_param('ScalingGroupName.6', ScalingGroupName6)
	def get_ScalingGroupName12(self): # String
		return self.get_query_params().get('ScalingGroupName.12')

	def set_ScalingGroupName12(self, ScalingGroupName12):  # String
		self.add_query_param('ScalingGroupName.12', ScalingGroupName12)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkess.endpoint import endpoint_data

class DescribeAlarmsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ess', '2014-08-28', 'DescribeAlarms','ess')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_MetricType(self): # String
		return self.get_query_params().get('MetricType')

	def set_MetricType(self, MetricType):  # String
		self.add_query_param('MetricType', MetricType)
	def get_ScalingGroupId(self): # String
		return self.get_query_params().get('ScalingGroupId')

	def set_ScalingGroupId(self, ScalingGroupId):  # String
		self.add_query_param('ScalingGroupId', ScalingGroupId)
	def get_PageNumber(self): # Integer
		return self.get_query_params().get('PageNumber')

	def set_PageNumber(self, PageNumber):  # Integer
		self.add_query_param('PageNumber', PageNumber)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_State(self): # String
		return self.get_query_params().get('State')

	def set_State(self, State):  # String
		self.add_query_param('State', State)
	def get_MetricName(self): # String
		return self.get_query_params().get('MetricName')

	def set_MetricName(self, MetricName):  # String
		self.add_query_param('MetricName', MetricName)
	def get_ResourceOwnerAccount(self): # String
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_AlarmTaskId(self): # String
		return self.get_query_params().get('AlarmTaskId')

	def set_AlarmTaskId(self, AlarmTaskId):  # String
		self.add_query_param('AlarmTaskId', AlarmTaskId)
	def get_IsEnable(self): # Boolean
		return self.get_query_params().get('IsEnable')

	def set_IsEnable(self, IsEnable):  # Boolean
		self.add_query_param('IsEnable', IsEnable)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkess.endpoint import endpoint_data

class CreateAlarmRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ess', '2014-08-28', 'CreateAlarm','ess')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_MetricType(self): # String
		return self.get_query_params().get('MetricType')

	def set_MetricType(self, MetricType):  # String
		self.add_query_param('MetricType', MetricType)
	def get_ScalingGroupId(self): # String
		return self.get_query_params().get('ScalingGroupId')

	def set_ScalingGroupId(self, ScalingGroupId):  # String
		self.add_query_param('ScalingGroupId', ScalingGroupId)
	def get_Description(self): # String
		return self.get_query_params().get('Description')

	def set_Description(self, Description):  # String
		self.add_query_param('Description', Description)
	def get_AlarmActions(self): # RepeatList
		return self.get_query_params().get('AlarmAction')

	def set_AlarmActions(self, AlarmAction):  # RepeatList
		for depth1 in range(len(AlarmAction)):
			self.add_query_param('AlarmAction.' + str(depth1 + 1), AlarmAction[depth1])
	def get_Threshold(self): # Float
		return self.get_query_params().get('Threshold')

	def set_Threshold(self, Threshold):  # Float
		self.add_query_param('Threshold', Threshold)
	def get_Effective(self): # String
		return self.get_query_params().get('Effective')

	def set_Effective(self, Effective):  # String
		self.add_query_param('Effective', Effective)
	def get_EvaluationCount(self): # Integer
		return self.get_query_params().get('EvaluationCount')

	def set_EvaluationCount(self, EvaluationCount):  # Integer
		self.add_query_param('EvaluationCount', EvaluationCount)
	def get_MetricName(self): # String
		return self.get_query_params().get('MetricName')

	def set_MetricName(self, MetricName):  # String
		self.add_query_param('MetricName', MetricName)
	def get_Dimensions(self): # RepeatList
		return self.get_query_params().get('Dimension')

	def set_Dimensions(self, Dimension):  # RepeatList
		for depth1 in range(len(Dimension)):
			if Dimension[depth1].get('DimensionValue') is not None:
				self.add_query_param('Dimension.' + str(depth1 + 1) + '.DimensionValue', Dimension[depth1].get('DimensionValue'))
			if Dimension[depth1].get('DimensionKey') is not None:
				self.add_query_param('Dimension.' + str(depth1 + 1) + '.DimensionKey', Dimension[depth1].get('DimensionKey'))
	def get_Period(self): # Integer
		return self.get_query_params().get('Period')

	def set_Period(self, Period):  # Integer
		self.add_query_param('Period', Period)
	def get_ResourceOwnerAccount(self): # String
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
	def get_GroupId(self): # Integer
		return self.get_query_params().get('GroupId')

	def set_GroupId(self, GroupId):  # Integer
		self.add_query_param('GroupId', GroupId)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_Name(self): # String
		return self.get_query_params().get('Name')

	def set_Name(self, Name):  # String
		self.add_query_param('Name', Name)
	def get_ComparisonOperator(self): # String
		return self.get_query_params().get('ComparisonOperator')

	def set_ComparisonOperator(self, ComparisonOperator):  # String
		self.add_query_param('ComparisonOperator', ComparisonOperator)
	def get_Statistics(self): # String
		return self.get_query_params().get('Statistics')

	def set_Statistics(self, Statistics):  # String
		self.add_query_param('Statistics', Statistics)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkess.endpoint import endpoint_data

class ModifyScalingConfigurationRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ess', '2014-08-28', 'ModifyScalingConfiguration','ess')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_HpcClusterId(self): # String
		return self.get_query_params().get('HpcClusterId')

	def set_HpcClusterId(self, HpcClusterId):  # String
		self.add_query_param('HpcClusterId', HpcClusterId)
	def get_KeyPairName(self): # String
		return self.get_query_params().get('KeyPairName')

	def set_KeyPairName(self, KeyPairName):  # String
		self.add_query_param('KeyPairName', KeyPairName)
	def get_SpotPriceLimits(self): # RepeatList
		return self.get_query_params().get('SpotPriceLimit')

	def set_SpotPriceLimits(self, SpotPriceLimit):  # RepeatList
		for depth1 in range(len(SpotPriceLimit)):
			if SpotPriceLimit[depth1].get('InstanceType') is not None:
				self.add_query_param('SpotPriceLimit.' + str(depth1 + 1) + '.InstanceType', SpotPriceLimit[depth1].get('InstanceType'))
			if SpotPriceLimit[depth1].get('PriceLimit') is not None:
				self.add_query_param('SpotPriceLimit.' + str(depth1 + 1) + '.PriceLimit', SpotPriceLimit[depth1].get('PriceLimit'))
	def get_ResourceGroupId(self): # String
		return self.get_query_params().get('ResourceGroupId')

	def set_ResourceGroupId(self, ResourceGroupId):  # String
		self.add_query_param('ResourceGroupId', ResourceGroupId)
	def get_PrivatePoolOptionsMatchCriteria(self): # String
		return self.get_query_params().get('PrivatePoolOptions.MatchCriteria')

	def set_PrivatePoolOptionsMatchCriteria(self, PrivatePoolOptionsMatchCriteria):  # String
		self.add_query_param('PrivatePoolOptions.MatchCriteria', PrivatePoolOptionsMatchCriteria)
	def get_HostName(self): # String
		return self.get_query_params().get('HostName')

	def set_HostName(self, HostName):  # String
		self.add_query_param('HostName', HostName)
	def get_InstanceDescription(self): # String
		return self.get_query_params().get('InstanceDescription')

	def set_InstanceDescription(self, InstanceDescription):  # String
		self.add_query_param('InstanceDescription', InstanceDescription)
	def get_SystemDiskAutoSnapshotPolicyId(self): # String
		return self.get_query_params().get('SystemDisk.AutoSnapshotPolicyId')

	def set_SystemDiskAutoSnapshotPolicyId(self, SystemDiskAutoSnapshotPolicyId):  # String
		self.add_query_param('SystemDisk.AutoSnapshotPolicyId', SystemDiskAutoSnapshotPolicyId)
	def get_PrivatePoolOptionsId(self): # String
		return self.get_query_params().get('PrivatePoolOptions.Id')

	def set_PrivatePoolOptionsId(self, PrivatePoolOptionsId):  # String
		self.add_query_param('PrivatePoolOptions.Id', PrivatePoolOptionsId)
	def get_Ipv6AddressCount(self): # Integer
		return self.get_query_params().get('Ipv6AddressCount')

	def set_Ipv6AddressCount(self, Ipv6AddressCount):  # Integer
		self.add_query_param('Ipv6AddressCount', Ipv6AddressCount)
	def get_Cpu(self): # Integer
		return self.get_query_params().get('Cpu')

	def set_Cpu(self, Cpu):  # Integer
		self.add_query_param('Cpu', Cpu)
	def get_SystemDiskCategoriess(self): # RepeatList
		return self.get_query_params().get('SystemDiskCategories')

	def set_SystemDiskCategoriess(self, SystemDiskCategories):  # RepeatList
		for depth1 in range(len(SystemDiskCategories)):
			self.add_query_param('SystemDiskCategories.' + str(depth1 + 1), SystemDiskCategories[depth1])
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_ScalingConfigurationName(self): # String
		return self.get_query_params().get('ScalingConfigurationName')

	def set_ScalingConfigurationName(self, ScalingConfigurationName):  # String
		self.add_query_param('ScalingConfigurationName', ScalingConfigurationName)
	def get_Tags(self): # String
		return self.get_query_params().get('Tags')

	def set_Tags(self, Tags):  # String
		self.add_query_param('Tags', Tags)
	def get_ScalingConfigurationId(self): # String
		return self.get_query_params().get('ScalingConfigurationId')

	def set_ScalingConfigurationId(self, ScalingConfigurationId):  # String
		self.add_query_param('ScalingConfigurationId', ScalingConfigurationId)
	def get_SpotStrategy(self): # String
		return self.get_query_params().get('SpotStrategy')

	def set_SpotStrategy(self, SpotStrategy):  # String
		self.add_query_param('SpotStrategy', SpotStrategy)
	def get_InstanceName(self): # String
		return self.get_query_params().get('InstanceName')

	def set_InstanceName(self, InstanceName):  # String
		self.add_query_param('InstanceName', InstanceName)
	def get_InternetChargeType(self): # String
		return self.get_query_params().get('InternetChargeType')

	def set_InternetChargeType(self, InternetChargeType):  # String
		self.add_query_param('InternetChargeType', InternetChargeType)
	def get_ZoneId(self): # String
		return self.get_query_params().get('ZoneId')

	def set_ZoneId(self, ZoneId):  # String
		self.add_query_param('ZoneId', ZoneId)
	def get_InstancePatternInfos(self): # RepeatList
		return self.get_query_params().get('InstancePatternInfo')

	def set_InstancePatternInfos(self, InstancePatternInfo):  # RepeatList
		for depth1 in range(len(InstancePatternInfo)):
			if InstancePatternInfo[depth1].get('Cores') is not None:
				self.add_query_param('InstancePatternInfo.' + str(depth1 + 1) + '.Cores', InstancePatternInfo[depth1].get('Cores'))
			if InstancePatternInfo[depth1].get('InstanceFamilyLevel') is not None:
				self.add_query_param('InstancePatternInfo.' + str(depth1 + 1) + '.InstanceFamilyLevel', InstancePatternInfo[depth1].get('InstanceFamilyLevel'))
			if InstancePatternInfo[depth1].get('Memory') is not None:
				self.add_query_param('InstancePatternInfo.' + str(depth1 + 1) + '.Memory', InstancePatternInfo[depth1].get('Memory'))
			if InstancePatternInfo[depth1].get('MaxPrice') is not None:
				self.add_query_param('InstancePatternInfo.' + str(depth1 + 1) + '.MaxPrice', InstancePatternInfo[depth1].get('MaxPrice'))
	def get_Affinity(self): # String
		return self.get_query_params().get('Affinity')

	def set_Affinity(self, Affinity):  # String
		self.add_query_param('Affinity', Affinity)
	def get_ImageId(self): # String
		return self.get_query_params().get('ImageId')

	def set_ImageId(self, ImageId):  # String
		self.add_query_param('ImageId', ImageId)
	def get_Memory(self): # Integer
		return self.get_query_params().get('Memory')

	def set_Memory(self, Memory):  # Integer
		self.add_query_param('Memory', Memory)
	def get_SpotInterruptionBehavior(self): # String
		return self.get_query_params().get('SpotInterruptionBehavior')

	def set_SpotInterruptionBehavior(self, SpotInterruptionBehavior):  # String
		self.add_query_param('SpotInterruptionBehavior', SpotInterruptionBehavior)
	def get_IoOptimized(self): # String
		return self.get_query_params().get('IoOptimized')

	def set_IoOptimized(self, IoOptimized):  # String
		self.add_query_param('IoOptimized', IoOptimized)
	def get_InstanceTypess(self): # RepeatList
		return self.get_query_params().get('InstanceTypes')

	def set_InstanceTypess(self, InstanceTypes):  # RepeatList
		for depth1 in range(len(InstanceTypes)):
			self.add_query_param('InstanceTypes.' + str(depth1 + 1), InstanceTypes[depth1])
	def get_InternetMaxBandwidthOut(self): # Integer
		return self.get_query_params().get('InternetMaxBandwidthOut')

	def set_InternetMaxBandwidthOut(self, InternetMaxBandwidthOut):  # Integer
		self.add_query_param('InternetMaxBandwidthOut', InternetMaxBandwidthOut)
	def get_SecurityGroupId(self): # String
		return self.get_query_params().get('SecurityGroupId')

	def set_SecurityGroupId(self, SecurityGroupId):  # String
		self.add_query_param('SecurityGroupId', SecurityGroupId)
	def get_SystemDiskKMSKeyId(self): # String
		return self.get_query_params().get('SystemDisk.KMSKeyId')

	def set_SystemDiskKMSKeyId(self, SystemDiskKMSKeyId):  # String
		self.add_query_param('SystemDisk.KMSKeyId', SystemDiskKMSKeyId)
	def get_SystemDiskCategory(self): # String
		return self.get_query_params().get('SystemDisk.Category')

	def set_SystemDiskCategory(self, SystemDiskCategory):  # String
		self.add_query_param('SystemDisk.Category', SystemDiskCategory)
	def get_SystemDiskPerformanceLevel(self): # String
		return self.get_query_params().get('SystemDisk.PerformanceLevel')

	def set_SystemDiskPerformanceLevel(self, SystemDiskPerformanceLevel):  # String
		self.add_query_param('SystemDisk.PerformanceLevel', SystemDiskPerformanceLevel)
	def get_UserData(self): # String
		return self.get_query_params().get('UserData')

	def set_UserData(self, UserData):  # String
		self.add_query_param('UserData', UserData)
	def get_PasswordInherit(self): # Boolean
		return self.get_query_params().get('PasswordInherit')

	def set_PasswordInherit(self, PasswordInherit):  # Boolean
		self.add_query_param('PasswordInherit', PasswordInherit)
	def get_ImageName(self): # String
		return self.get_query_params().get('ImageName')

	def set_ImageName(self, ImageName):  # String
		self.add_query_param('ImageName', ImageName)
	def get_Override(self): # Boolean
		return self.get_query_params().get('Override')

	def set_Override(self, Override):  # Boolean
		self.add_query_param('Override', Override)
	def get_SchedulerOptions(self): # Json
		return self.get_query_params().get('SchedulerOptions')

	def set_SchedulerOptions(self, SchedulerOptions):  # Json
		self.add_query_param('SchedulerOptions', SchedulerOptions)
	def get_DeploymentSetId(self): # String
		return self.get_query_params().get('DeploymentSetId')

	def set_DeploymentSetId(self, DeploymentSetId):  # String
		self.add_query_param('DeploymentSetId', DeploymentSetId)
	def get_ResourceOwnerAccount(self): # String
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
	def get_OwnerAccount(self): # String
		return self.get_query_params().get('OwnerAccount')

	def set_OwnerAccount(self, OwnerAccount):  # String
		self.add_query_param('OwnerAccount', OwnerAccount)
	def get_Tenancy(self): # String
		return self.get_query_params().get('Tenancy')

	def set_Tenancy(self, Tenancy):  # String
		self.add_query_param('Tenancy', Tenancy)
	def get_SystemDiskDiskName(self): # String
		return self.get_query_params().get('SystemDisk.DiskName')

	def set_SystemDiskDiskName(self, SystemDiskDiskName):  # String
		self.add_query_param('SystemDisk.DiskName', SystemDiskDiskName)
	def get_RamRoleName(self): # String
		return self.get_query_params().get('RamRoleName')

	def set_RamRoleName(self, RamRoleName):  # String
		self.add_query_param('RamRoleName', RamRoleName)
	def get_SystemDiskEncryptAlgorithm(self): # String
		return self.get_query_params().get('SystemDisk.EncryptAlgorithm')

	def set_SystemDiskEncryptAlgorithm(self, SystemDiskEncryptAlgorithm):  # String
		self.add_query_param('SystemDisk.EncryptAlgorithm', SystemDiskEncryptAlgorithm)
	def get_DedicatedHostId(self): # String
		return self.get_query_params().get('DedicatedHostId')

	def set_DedicatedHostId(self, DedicatedHostId):  # String
		self.add_query_param('DedicatedHostId', DedicatedHostId)
	def get_CreditSpecification(self): # String
		return self.get_query_params().get('CreditSpecification')

	def set_CreditSpecification(self, CreditSpecification):  # String
		self.add_query_param('CreditSpecification', CreditSpecification)
	def get_SpotDuration(self): # Integer
		return self.get_query_params().get('SpotDuration')

	def set_SpotDuration(self, SpotDuration):  # Integer
		self.add_query_param('SpotDuration', SpotDuration)
	def get_SecurityGroupIdss(self): # RepeatList
		return self.get_query_params().get('SecurityGroupIds')

	def set_SecurityGroupIdss(self, SecurityGroupIds):  # RepeatList
		for depth1 in range(len(SecurityGroupIds)):
			self.add_query_param('SecurityGroupIds.' + str(depth1 + 1), SecurityGroupIds[depth1])
	def get_DataDisks(self): # RepeatList
		return self.get_query_params().get('DataDisk')

	def set_DataDisks(self, DataDisk):  # RepeatList
		for depth1 in range(len(DataDisk)):
			if DataDisk[depth1].get('DiskName') is not None:
				self.add_query_param('DataDisk.' + str(depth1 + 1) + '.DiskName', DataDisk[depth1].get('DiskName'))
			if DataDisk[depth1].get('SnapshotId') is not None:
				self.add_query_param('DataDisk.' + str(depth1 + 1) + '.SnapshotId', DataDisk[depth1].get('SnapshotId'))
			if DataDisk[depth1].get('Encrypted') is not None:
				self.add_query_param('DataDisk.' + str(depth1 + 1) + '.Encrypted', DataDisk[depth1].get('Encrypted'))
			if DataDisk[depth1].get('Size') is not None:
				self.add_query_param('DataDisk.' + str(depth1 + 1) + '.Size', DataDisk[depth1].get('Size'))
			if DataDisk[depth1].get('PerformanceLevel') is not None:
				self.add_query_param('DataDisk.' + str(depth1 + 1) + '.PerformanceLevel', DataDisk[depth1].get('PerformanceLevel'))
			if DataDisk[depth1].get('AutoSnapshotPolicyId') is not None:
				self.add_query_param('DataDisk.' + str(depth1 + 1) + '.AutoSnapshotPolicyId', DataDisk[depth1].get('AutoSnapshotPolicyId'))
			if DataDisk[depth1].get('Description') is not None:
				self.add_query_param('DataDisk.' + str(depth1 + 1) + '.Description', DataDisk[depth1].get('Description'))
			if DataDisk[depth1].get('Categories') is not None:
				for depth2 in range(len(DataDisk[depth1].get('Categories'))):
					self.add_query_param('DataDisk.' + str(depth1 + 1) + '.Categories' + str(depth2 + 1), DataDisk[depth1].get('Categories')[depth2])
			if DataDisk[depth1].get('Category') is not None:
				self.add_query_param('DataDisk.' + str(depth1 + 1) + '.Category', DataDisk[depth1].get('Category'))
			if DataDisk[depth1].get('KMSKeyId') is not None:
				self.add_query_param('DataDisk.' + str(depth1 + 1) + '.KMSKeyId', DataDisk[depth1].get('KMSKeyId'))
			if DataDisk[depth1].get('Device') is not None:
				self.add_query_param('DataDisk.' + str(depth1 + 1) + '.Device', DataDisk[depth1].get('Device'))
			if DataDisk[depth1].get('DeleteWithInstance') is not None:
				self.add_query_param('DataDisk.' + str(depth1 + 1) + '.DeleteWithInstance', DataDisk[depth1].get('DeleteWithInstance'))
	def get_InstanceTypeOverrides(self): # RepeatList
		return self.get_query_params().get('InstanceTypeOverride')

	def set_InstanceTypeOverrides(self, InstanceTypeOverride):  # RepeatList
		for depth1 in range(len(InstanceTypeOverride)):
			if InstanceTypeOverride[depth1].get('WeightedCapacity') is not None:
				self.add_query_param('InstanceTypeOverride.' + str(depth1 + 1) + '.WeightedCapacity', InstanceTypeOverride[depth1].get('WeightedCapacity'))
			if InstanceTypeOverride[depth1].get('InstanceType') is not None:
				self.add_query_param('InstanceTypeOverride.' + str(depth1 + 1) + '.InstanceType', InstanceTypeOverride[depth1].get('InstanceType'))
	def get_LoadBalancerWeight(self): # Integer
		return self.get_query_params().get('LoadBalancerWeight')

	def set_LoadBalancerWeight(self, LoadBalancerWeight):  # Integer
		self.add_query_param('LoadBalancerWeight', LoadBalancerWeight)
	def get_SystemDiskSize(self): # Integer
		return self.get_query_params().get('SystemDisk.Size')

	def set_SystemDiskSize(self, SystemDiskSize):  # Integer
		self.add_query_param('SystemDisk.Size', SystemDiskSize)
	def get_ImageFamily(self): # String
		return self.get_query_params().get('ImageFamily')

	def set_ImageFamily(self, ImageFamily):  # String
		self.add_query_param('ImageFamily', ImageFamily)
	def get_SystemDiskDescription(self): # String
		return self.get_query_params().get('SystemDisk.Description')

	def set_SystemDiskDescription(self, SystemDiskDescription):  # String
		self.add_query_param('SystemDisk.Description', SystemDiskDescription)
	def get_SystemDiskEncrypted(self): # Boolean
		return self.get_query_params().get('SystemDisk.Encrypted')

	def set_SystemDiskEncrypted(self, SystemDiskEncrypted):  # Boolean
		self.add_query_param('SystemDisk.Encrypted', SystemDiskEncrypted)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkess.endpoint import endpoint_data

class CreateScheduledTaskRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ess', '2014-08-28', 'CreateScheduledTask','ess')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ScheduledAction(self): # String
		return self.get_query_params().get('ScheduledAction')

	def set_ScheduledAction(self, ScheduledAction):  # String
		self.add_query_param('ScheduledAction', ScheduledAction)
	def get_MaxValue(self): # Integer
		return self.get_query_params().get('MaxValue')

	def set_MaxValue(self, MaxValue):  # Integer
		self.add_query_param('MaxValue', MaxValue)
	def get_ScalingGroupId(self): # String
		return self.get_query_params().get('ScalingGroupId')

	def set_ScalingGroupId(self, ScalingGroupId):  # String
		self.add_query_param('ScalingGroupId', ScalingGroupId)
	def get_Description(self): # String
		return self.get_query_params().get('Description')

	def set_Description(self, Description):  # String
		self.add_query_param('Description', Description)
	def get_RecurrenceEndTime(self): # String
		return self.get_query_params().get('RecurrenceEndTime')

	def set_RecurrenceEndTime(self, RecurrenceEndTime):  # String
		self.add_query_param('RecurrenceEndTime', RecurrenceEndTime)
	def get_LaunchTime(self): # String
		return self.get_query_params().get('LaunchTime')

	def set_LaunchTime(self, LaunchTime):  # String
		self.add_query_param('LaunchTime', LaunchTime)
	def get_DesiredCapacity(self): # Integer
		return self.get_query_params().get('DesiredCapacity')

	def set_DesiredCapacity(self, DesiredCapacity):  # Integer
		self.add_query_param('DesiredCapacity', DesiredCapacity)
	def get_ResourceOwnerAccount(self): # String
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
	def get_OwnerAccount(self): # String
		return self.get_query_params().get('OwnerAccount')

	def set_OwnerAccount(self, OwnerAccount):  # String
		self.add_query_param('OwnerAccount', OwnerAccount)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_RecurrenceValue(self): # String
		return self.get_query_params().get('RecurrenceValue')

	def set_RecurrenceValue(self, RecurrenceValue):  # String
		self.add_query_param('RecurrenceValue', RecurrenceValue)
	def get_LaunchExpirationTime(self): # Integer
		return self.get_query_params().get('LaunchExpirationTime')

	def set_LaunchExpirationTime(self, LaunchExpirationTime):  # Integer
		self.add_query_param('LaunchExpirationTime', LaunchExpirationTime)
	def get_MinValue(self): # Integer
		return self.get_query_params().get('MinValue')

	def set_MinValue(self, MinValue):  # Integer
		self.add_query_param('MinValue', MinValue)
	def get_ScheduledTaskName(self): # String
		return self.get_query_params().get('ScheduledTaskName')

	def set_ScheduledTaskName(self, ScheduledTaskName):  # String
		self.add_query_param('ScheduledTaskName', ScheduledTaskName)
	def get_TaskEnabled(self): # Boolean
		return self.get_query_params().get('TaskEnabled')

	def set_TaskEnabled(self, TaskEnabled):  # Boolean
		self.add_query_param('TaskEnabled', TaskEnabled)
	def get_RecurrenceType(self): # String
		return self.get_query_params().get('RecurrenceType')

	def set_RecurrenceType(self, RecurrenceType):  # String
		self.add_query_param('RecurrenceType', RecurrenceType)
